@@ -520,3 +520,17 @@ class varsShare:
             return False
         return open('/proc/1/mountinfo','r').read() != \
                open('/proc/self/mountinfo','r').read()
+
+    def getProgPath(self,progname):
+        """Get full path of program or False"""
+        baseprogname = os.path.basename(progname)
+        env = {"LANG":"C"}
+        env.update(os.environ.items() + [("PATH",getpathenv())] +\
+                   env.items())
+        res = self._runos("which %s"%progname,env=env)
+        if res:
+            return res[0].strip()
+        elif os.path.isabs(progname) and os.path.exists(progname):
+            return progname
+        else:
+            return False
